@@ -5,6 +5,7 @@ require 'uri'
 require 'zlib'
 require 'multi_xml'
 require 'json'
+require 'csv'
 
 require 'httparty/module_inheritable_attributes'
 require 'httparty/cookie_hash'
@@ -282,6 +283,17 @@ module HTTParty
       default_options[:pem_password] = password
     end
 
+    # Allows setting a PKCS12 file to be used
+    #
+    #   class Foo
+    #     include HTTParty
+    #     pkcs12 File.read('/home/user/my.p12'), "password"
+    #   end
+    def pkcs12(p12_contents, password)
+      default_options[:p12] = p12_contents
+      default_options[:p12_password] = password
+    end
+
     # Override the way query strings are normalized.
     # Helpful for overriding the default rails normalization of Array queries.
     #
@@ -481,11 +493,18 @@ module HTTParty
     private
 
       def perform_request(http_method, path, options, &block) #:nodoc:
-        options = default_options.dup.merge(options)
+        options = default_options.merge(options)
+        process_headers(options)
         process_cookies(options)
         Request.new(http_method, path, options).perform(&block)
       end
 
+      def process_headers(options)
+        if options[:headers] && headers.any?
+          options[:headers] = headers.merge(options[:headers])
+        end
+      end
+
       def process_cookies(options) #:nodoc:
         return unless options[:cookies] || default_cookies.any?
         options[:headers] ||= headers.dup
@@ -539,7 +558,7 @@ module HTTParty
   end
 
   def self.copy(*args, &block)
-    Basement.move(*args, &block)
+    Basement.copy(*args, &block)
   end
 
   def self.head(*args, &block)
