@@ -21,8 +21,8 @@ describe HTTParty::Request do
       end
 
       it "URI encodes array values" do
-        query_string = normalizer[{:people => ["Bob Marley", "Tim & Jon"]}]
-        query_string.should == "people=Bob%20Marley&people=Tim%20%26%20Jon"
+        query_string = normalizer[{:people => ["Otis Redding", "Bob Marley", "Tim & Jon"], :page => 1, :xyzzy => 3}]
+        query_string.should == "page=1&people=Otis%20Redding&people=Bob%20Marley&people=Tim%20%26%20Jon&xyzzy=3"
       end
     end
 
@@ -133,6 +133,12 @@ describe HTTParty::Request do
         URI.unescape(@request.uri.query).should == ""
       end
 
+      it "does not append an ampersand when queries are embedded in paths" do
+        @request.path = "/path?a=1"
+        @request.options[:query] = {}
+        @request.uri.query.should == "a=1"
+      end
+
       it "does not duplicate query string parameters when uri is called twice" do
         @request.options[:query] = {:foo => :bar}
         @request.uri
@@ -196,6 +202,24 @@ describe HTTParty::Request do
       end
     end
 
+    it 'should handle text/csv' do
+      ["text/csv", "text/csv; charset=iso8859-1"].each do |ct|
+        @request.send(:format_from_mimetype, ct).should == :csv
+      end
+    end
+
+    it 'should handle application/csv' do
+      ["application/csv", "application/csv; charset=iso8859-1"].each do |ct|
+        @request.send(:format_from_mimetype, ct).should == :csv
+      end
+    end
+
+    it 'should handle text/comma-separated-values' do
+      ["text/comma-separated-values", "text/comma-separated-values; charset=iso8859-1"].each do |ct|
+        @request.send(:format_from_mimetype, ct).should == :csv
+      end
+    end
+
     it 'should handle text/javascript' do
       ["text/javascript", "text/javascript; charset=iso8859-1"].each do |ct|
         @request.send(:format_from_mimetype, ct).should == :plain
@@ -225,6 +249,12 @@ describe HTTParty::Request do
       @request.send(:parse_response, xml).should == {'books' => {'book' => {'id' => '1234', 'name' => 'Foo Bar!'}}}
     end
 
+    it 'should handle csv automatically' do
+      csv=[%q["id","Name"],%q["1234","Foo Bar!"]].join("\n")
+      @request.options[:format] = :csv
+      @request.send(:parse_response, csv).should == [["id","Name"],["1234","Foo Bar!"]]
+    end
+
     it 'should handle json automatically' do
       json = %q[{"books": {"book": {"name": "Foo Bar!", "id": "1234"}}}]
       @request.options[:format] = :json
