@@ -38,6 +38,18 @@ describe HTTParty do
     end
   end
 
+  describe "pkcs12" do
+    it 'should set the p12 content' do
+      @klass.pkcs12 'P12-CONTENT', 'PASSWORD'
+      @klass.default_options[:p12].should == 'P12-CONTENT'
+    end
+
+    it 'should set the password' do
+      @klass.pkcs12 'P12-CONTENT', 'PASSWORD'
+      @klass.default_options[:p12_password].should == 'PASSWORD'
+    end
+  end
+
   describe 'ssl_version' do
     it 'should set the ssl_version content' do
       @klass.ssl_version :SSLv3
@@ -148,12 +160,18 @@ describe HTTParty do
       @klass.get('')
     end
 
-    it "overwrites class headers when passing in headers" do
-      expect_headers(:baz => 'spax')
+    it "merges class headers with request headers" do
+      expect_headers(:baz => 'spax', :foo => 'bar')
       @klass.headers(:foo => 'bar')
       @klass.get('', :headers => {:baz => 'spax'})
     end
 
+    it 'overrides class headers with request headers' do
+      expect_headers(:baz => 'spax', :foo => 'baz')
+      @klass.headers(:foo => 'bar')
+      @klass.get('', :headers => {:baz => 'spax', :foo => 'baz'})
+    end
+
     context "with cookies" do
       it 'utilizes the class-level cookies' do
         expect_headers(:foo => 'bar', 'cookie' => 'type=snickerdoodle')
@@ -379,6 +397,11 @@ describe HTTParty do
       @klass.default_options[:format].should == :xml
     end
 
+    it "should allow csv" do
+      @klass.format :csv
+      @klass.default_options[:format].should == :csv
+    end
+
     it "should allow json" do
       @klass.format :json
       @klass.default_options[:format].should == :json
@@ -398,7 +421,7 @@ describe HTTParty do
     it 'should only print each format once with an exception' do
       lambda do
         @klass.format :foobar
-      end.should raise_error(HTTParty::UnsupportedFormat, "':foobar' Must be one of: html, json, plain, xml")
+      end.should raise_error(HTTParty::UnsupportedFormat, "':foobar' Must be one of: csv, html, json, plain, xml")
     end
 
     it 'sets the default parser' do
@@ -691,6 +714,14 @@ describe HTTParty do
       }
     end
 
+    it "should be able parse response type csv automatically" do
+      stub_http_response_with('twitter.csv')
+      profile = HTTParty.get('http://twitter.com/statuses/profile.csv')
+      profile.size.should == 2
+      profile[0].should == ["name","url","id","description","protected","screen_name","followers_count","profile_image_url","location"]
+      profile[1].should == ["Magic 8 Bot",nil,"17656026","ask me a question","false","magic8bot","90","http://s3.amazonaws.com/twitter_production/profile_images/65565851/8ball_large_normal.jpg",nil]
+    end
+
     it "should not get undefined method add_node for nil class for the following xml" do
       stub_http_response_with('undefined_method_add_node_for_nil.xml')
       result = HTTParty.get('http://foobar.com')
